pub struct Engine<S, C = NoCache> { /* private fields */ }Expand description
RBAC engine with pluggable store and optional cache.
Implementations
Sourceimpl<S, C> Engine<S, C>
impl<S, C> Engine<S, C>
Authorizes a principal for a permission within a tenant.
Authorizes a principal for a permission within a tenant.
Sourcepub async fn scope(
&self,
tenant: TenantId,
principal: PrincipalId,
resource: ResourceName,
) -> Result<Scope>
pub async fn scope( &self, tenant: TenantId, principal: PrincipalId, resource: ResourceName, ) -> Result<Scope>
Computes scope for a resource within a tenant.
Sourcepub async fn scope_ref(
&self,
tenant: &TenantId,
principal: &PrincipalId,
resource: &ResourceName,
) -> Result<Scope>
pub async fn scope_ref( &self, tenant: &TenantId, principal: &PrincipalId, resource: &ResourceName, ) -> Result<Scope>
Computes scope for a resource within a tenant.